@@ -20,7 +20,6 @@
 import os
 import os.path
 import sys
-import platform
 
 CLARA_AGX_XAVIER = 'CLARA_AGX_XAVIER'
 JETSON_NX = 'JETSON_NX'
@@ -49,13 +48,13 @@ JETSON_ORIN='JETSON_ORIN'
 # mode numbers to the Linux GPIO pin number and GPIO chip directory
 
 JETSON_ORIN_PIN_DEFS = [
-    ({164: 106}, {164:  'PQ.06'}, "2200000.gpio", 7, 4, 'GPIO40', 'GP66', None, None),
+    ({164: 106}, {164:  'PQ.06'}, "2200000.gpio", 7, 4, 'MCLK05', 'GP66', None, None),
     # Output-only (due to base board)
     ({164: 112}, {164:  'PR.04'}, "2200000.gpio", 11, 17, 'UART1_RTS', 'GP72_UART1_RTS_N', None, None),
     ({164:  50}, {164:  'PH.07'}, "2200000.gpio", 12, 18, 'I2S2_CLK', 'GP122', None, None),
-    ({164:  108}, {164:  'PR.00'}, "2200000.gpio", 13, 27, 'GPIO32', 'GP58', None, None),
+    ({164:  108}, {164:  'PR.00'}, "2200000.gpio", 13, 27, 'PWM01', 'GP68', None, None),
     ({164:  85}, {164:  'PN.01'}, "2200000.gpio", 15, 22, 'GPIO27', 'GP88_PWM1', '3280000.pwm', 0),
-    ({32:   9}, { 32: 'PBB.01'}, "c2f0000.gpio", 16, 23, 'GPIO8', 'GP25', None, None),
+    ({32:   9}, { 32: 'PBB.01'}, "c2f0000.gpio", 16, 23, 'GPIO08', 'GP26', None, None),
     ({164:  43}, {164:  'PH.00'}, "2200000.gpio", 18, 24, 'GPIO35', 'GP115', '32c0000.pwm', 0),
     ({164: 135}, {164:  'PZ.05'}, "2200000.gpio", 19, 10, 'SPI1_MOSI', 'GP49_SPI1_MOSI', None, None),
     ({164: 134}, {164:  'PZ.04'}, "2200000.gpio", 21, 9, 'SPI1_MISO', 'GP48_SPI1_MISO', None, None),
@@ -65,7 +64,7 @@ JETSON_ORIN_PIN_DEFS = [
     ({164: 137}, {164:  'PZ.07'}, "2200000.gpio", 26, 7, 'SPI1_CS1_N', 'GP51_SPI1_CS1_N', None, None),
     ({ 32:   1}, { 32: 'PAA.01'}, "c2f0000.gpio", 29, 5, 'CAN0_DIN', 'GP18_CAN0_DIN', None, None),
     ({ 32:   0}, { 32: 'PAA.00'}, "c2f0000.gpio", 31, 6, 'CAN0_DOUT', 'GP17_CAN0_DOUT', None, None),
-    ({ 32:  8}, { 32: 'PBB.00'}, "c2f0000.gpio", 32, 12, 'GPIO9', 'GP26', None, None),
+    ({ 32:  8}, { 32: 'PBB.00'}, "c2f0000.gpio", 32, 12, 'GPIO09', 'GP25', None, None),
     ({ 32:   2}, { 32: 'PAA.02'}, "c2f0000.gpio", 33, 13, 'CAN1_DOUT', 'GP19_CAN1_DOUT', None, None),
     ({164: 53}, {164:  'PI.02'}, "2200000.gpio", 35, 19, 'I2S2_FS', 'GP125', None, None),
     ({164: 113}, {164:  'PR.05'}, "2200000.gpio", 36, 16, 'UART1_CTS', 'GP73_UART1_CTS_N', None, None),
@@ -114,7 +113,7 @@ JETSON_NX_PIN_DEFS = [
     ({224: 140, 169: 112}, {169:  'PR.04'}, "2200000.gpio", 11, 17, 'UART1_RTS', 'UART1_RTS', None, None),
     ({224: 157, 169: 127}, {169:  'PT.05'}, "2200000.gpio", 12, 18, 'I2S0_SCLK', 'DAP5_SCLK', None, None),
     ({224: 192, 169: 149}, {169:  'PY.00'}, "2200000.gpio", 13, 27, 'SPI1_SCK', 'SPI3_SCK', None, None),
-    ({ 40:  20,  30:  16}, { 30: 'PCC.04'}, "c2f0000.gpio", 15, 22, 'GPIO12', 'TOUCH_CLK', None, None),
+    ({ 40:  20,  30:  16}, { 30: 'PCC.04'}, "c2f0000.gpio", 15, 22, 'GPIO12', 'TOUCH_CLK', "c340000.pwm", 0),
     ({224: 196, 169: 153}, {169:  'PY.04'}, "2200000.gpio", 16, 23, 'SPI1_CS1', 'SPI3_CS1_N', None, None),
     ({224: 195, 169: 152}, {169:  'PY.03'}, "2200000.gpio", 18, 24, 'SPI1_CS0', 'SPI3_CS0_N', None, None),
     ({224: 205, 169: 162}, {169:  'PZ.05'}, "2200000.gpio", 19, 10, 'SPI0_MOSI', 'SPI1_MOSI', None, None),
@@ -138,6 +137,7 @@ compats_nx = (
     'nvidia,p3509-0000+p3668-0001',
     'nvidia,p3449-0000+p3668-0000',
     'nvidia,p3449-0000+p3668-0001',
+    'nvidia,p3449-0000+p3668-0003',
 )
 
 JETSON_XAVIER_PIN_DEFS = [
@@ -332,7 +332,7 @@ jetson_gpio_data = {
         JETSON_NX_PIN_DEFS,
         {
             'P1_REVISION': 1,
-            'RAM': '16384M',
+            'RAM': '16384M, 8192M',
             'REVISION': 'Unknown',
             'TYPE': 'Jetson NX',
             'MANUFACTURER': 'NVIDIA',
@@ -343,7 +343,7 @@ jetson_gpio_data = {
         JETSON_XAVIER_PIN_DEFS,
         {
             'P1_REVISION': 1,
-            'RAM': '16384M',
+            'RAM': '65536M, 32768M, 16384M, 8192M',
             'REVISION': 'Unknown',
             'TYPE': 'Jetson Xavier',
             'MANUFACTURER': 'NVIDIA',
@@ -365,7 +365,7 @@ jetson_gpio_data = {
         JETSON_TX2_PIN_DEFS,
         {
             'P1_REVISION': 1,
-            'RAM': '8192M',
+            'RAM': '8192M, 4096M',
             'REVISION': 'Unknown',
             'TYPE': 'Jetson TX2',
             'MANUFACTURER': 'NVIDIA',
@@ -387,7 +387,7 @@ jetson_gpio_data = {
         JETSON_NANO_PIN_DEFS,
         {
             'P1_REVISION': 1,
-            'RAM': '4096M',
+            'RAM': '4096M, 2048M',
             'REVISION': 'Unknown',
             'TYPE': 'Jetson Nano',
             'MANUFACTURER': 'NVIDIA',
@@ -414,6 +414,7 @@ ids_warned = False
 def get_data():
     compatible_path = '/proc/device-tree/compatible'
     ids_path = '/proc/device-tree/chosen/plugin-manager/ids'
+    ids_path_k510 = '/proc/device-tree/chosen/ids'
 
     with open(compatible_path, 'r') as f:
         compatibles = f.read().split('\x00')
@@ -423,9 +424,17 @@ def get_data():
 
     def find_pmgr_board(prefix):
         global ids_warned
-        if not os.path.exists(ids_path):
-            if platform.uname()[2].startswith("5"):
-                return None
+        if os.path.exists(ids_path):
+            for f in os.listdir(ids_path):
+                if f.startswith(prefix):
+                    return f
+        elif os.path.exists(ids_path_k510):
+            with open(ids_path_k510, 'r') as f:
+                ids = f.read()
+                for s in ids.split():
+                    if s.startswith(prefix):
+                        return s
+        else:
             if not ids_warned:
                 ids_warned = True
                 msg = """\
@@ -434,9 +443,9 @@ WARNING: Cannot determine whether the expected Jetson board is present.
 """
                 sys.stderr.write(msg)
             return None
-        for f in os.listdir(ids_path):
-            if f.startswith(prefix):
-                return f
+
+
+
         return None
 
     def warn_if_not_carrier_board(*carrier_boards):
@@ -483,6 +492,7 @@ WARNING: and in fact is unlikely to work correctly.
         warn_if_not_carrier_board('3509', '3449')
     elif matches(compats_jetson_orins):
         model = JETSON_ORIN
+        warn_if_not_carrier_board('3737','0000')
     else:
         raise Exception('Could not determine Jetson model')
 
@@ -573,3 +583,4 @@ WARNING: and in fact is unlikely to work correctly.
     }
 
     return model, jetson_info, channel_data
+
